pitchtools.transpose_chromatic_pitch_class_number_to_chromatic_pitch_number_neighbor
====================================================================================

.. autofunction:: abjad.tools.pitchtools.transpose_chromatic_pitch_class_number_to_chromatic_pitch_number_neighbor.transpose_chromatic_pitch_class_number_to_chromatic_pitch_number_neighbor
   :noindex:
